@@ -9,11 +9,16 @@ import sqlalchemy_dao
 import sys
 
 class Dao(object):
+    session_class = Session
+    session_context_class = SessionContext
+    
     def __init__(self, url, pool_size=sqlalchemy_dao.POOL_DEFAULT):
-        pool_class = NullPool if pool_size == sqlalchemy_dao.POOL_DISABLED else None
-        self._engine = engine.create_engine(url, poolclass=pool_class, pool_size=pool_size,
-                max_overflow=sys.maxsize, pool_recycle=3600)
-        self._Session = session.sessionmaker(bind=self._engine, class_=Session)
+        if pool_size == sqlalchemy_dao.POOL_DISABLED:
+            self._engine = engine.create_engine(url, poolclass=NullPool)
+        else:
+            self._engine = engine.create_engine(url, pool_size=pool_size, pool_recycle=3600,
+                    max_overflow=sys.maxsize)
+        self._Session = session.sessionmaker(bind=self._engine, class_=self.session_class)
         
     def create_session(self):
         return self._Session()
@@ -22,5 +27,5 @@ class Dao(object):
         return Lock(self, name)
         
     def SessionContext(self, **kw):
-        return SessionContext(self, **kw)
+        return self.session_context_class(self, **kw)
     
\ No newline at end of file
