@@ -2,28 +2,33 @@
 from fixtures._fixtures.monkeypatch import MonkeyPatch
 from fixtures.fixture import Fixture
 from sqlalchemy_dao.dao import Dao
+import sqlalchemy_dao
 import subprocess
 
 class MysqlFixture(Fixture):
-    def __init__(self, sql_pathes, dao_pathes=None):
+    def __init__(self, scripts, daos=None):
         super(MysqlFixture, self).__init__()
-        self._sql_pathes = sql_pathes
-        self._dao_pathes = dao_pathes or []
+        self._scripts = scripts
+        self._daos = daos or []
         
     def setUp(self):
         super(MysqlFixture, self).setUp()
         self._init_db('test')
-        self._stub_daos()
+        self.dao = self._create_dao()
+        self._patch_daos()
+        
+    def _create_dao(self):
+        return Dao('mysql://test:test@localhost/test?charset=utf8',
+                pool_size=sqlalchemy_dao.POOL_DISABLED)
         
     def _init_db(self, database):
         _call_mysql('mysql --user=test --password=test -e "drop database if exists %s"' % database)
         _call_mysql('mysql --user=test --password=test -e "create database %s default character set utf8 default collate utf8_general_ci"' % database)
-        for path in self._sql_pathes:
-            _call_mysql('mysql --user=test --password=test %s <%s' % (database, path))
+        for script in self._scripts:
+            _call_mysql('mysql --user=test --password=test %s <%s' % (database, script))
             
-    def _stub_daos(self):
-        self.dao = Dao('mysql://test:test@localhost/test?charset=utf8')
-        for path in self._dao_pathes:
+    def _patch_daos(self):
+        for path in self._daos:
             self.useFixture(MonkeyPatch(path, self.dao))
             
 def _call_mysql(cmd):
